import { __assign } from "tslib";
/**
 * Load config for Cypress from environment variables. Loads
 * FIRESTORE_EMULATOR_HOST, FIREBASE_DATABASE_EMULATOR_HOST, and
 * GCLOUD_PROJECT variable values from environment to pass to
 * Cypress environment
 * @param cypressConfig - Existing Cypress config
 * @returns Cypress config extended with environment variables
 */
export default function extendWithFirebaseConfig(cypressConfig) {
    var newEnv = {};
    if (cypressConfig === null || cypressConfig === void 0 ? void 0 : cypressConfig.env) {
        newEnv = cypressConfig.env;
    }
    var _a = process.env, FIREBASE_DATABASE_EMULATOR_HOST = _a.FIREBASE_DATABASE_EMULATOR_HOST, FIRESTORE_EMULATOR_HOST = _a.FIRESTORE_EMULATOR_HOST, GCLOUD_PROJECT = _a.GCLOUD_PROJECT;
    if (FIRESTORE_EMULATOR_HOST && !newEnv.FIRESTORE_EMULATOR_HOST) {
        newEnv.FIRESTORE_EMULATOR_HOST = FIRESTORE_EMULATOR_HOST;
    }
    if (FIREBASE_DATABASE_EMULATOR_HOST &&
        !newEnv.FIREBASE_DATABASE_EMULATOR_HOST) {
        newEnv.FIREBASE_DATABASE_EMULATOR_HOST = FIREBASE_DATABASE_EMULATOR_HOST;
    }
    if (GCLOUD_PROJECT && !newEnv.GCLOUD_PROJECT) {
        newEnv.GCLOUD_PROJECT = GCLOUD_PROJECT;
    }
    // Return original config if baseUrl is already set (so it is not runover)
    return __assign(__assign({}, cypressConfig), { env: newEnv });
}
